# Generated by roxygen2: do not edit by hand

S3method(print,disagg_conjugate)
S3method(print,disagg_statespace)
S3method(print,summary.disagg_statespace)
S3method(summary,disagg_statespace)
export(align_disagg_inputs)
export(disagg_default_priors)
export(disagg_stan_code)
export(disaggregate_conjugate)
export(disaggregate_from_files)
export(disaggregate_statespace)
export(log_enable)
export(read_cpi)
export(read_weights_matrix)
export(simulate_disagg)
importFrom(magrittr,"%>%")
